==> snipe-it-7.0.13.zip: snipe-it-7.0.13/resources/lang/sv-SE/localizations.php <==
<?php

return [

    'select_language' => 'Select a Language',
    'languages' => [
        'en-US'=> 'Engelska, USA',
        'en-GB'=> 'Engelska, Storbritannien',
        'am-ET' => 'Amharic',
        'af-ZA'=> 'Afrikaans',
        'ar-SA'=> 'Arabiska',
        'bg-BG'=> 'Bulgariska',
        'zh-CN'=> 'Kinesiska, förenklad',
        'zh-TW'=> 'Kinesiska traditionell',
        'ca-ES' => 'Katalanska',
        'hr-HR'=> 'Kroatiska',
        'cs-CZ'=> 'Tjeckiska',
        'da-DK'=> 'Danska',
        'nl-NL'=> 'Nederländska',
        'en-ID'=> 'Engelska, Indonesien',
        'et-EE'=> 'Estniska',
        'fil-PH'=> 'Filippinska',
        'fi-FI'=> 'Finska',
        'fr-FR'=> 'Franska',
        'de-DE'=> 'Tyska',
        'de-if'=> 'Tyska (informellt)',
        'el-GR'=> 'Grekiska',
        'he-IL'=> 'Hebreiska',
        'hu-HU'=> 'Ungerska',
        'is-IS' => 'Isländska',
        'id-ID'=> 'Indonesiska',
        'ga-IE'=> 'Irländska',
        'it-IT'=> 'Italienska',
        'ja-JP'=> 'Japanska',
        'km-KH'=>'Khmer',
        'ko-KR'=> 'Koreanska',
        'lt-LT'=>'Litauiska',
        'lv-LV'=> 'Lettiska',
        'mk-MK'=> 'Makedonska',
        'ms-MY'=> 'Malajiska',
        'mi-NZ'=> 'Maori',
        'mn-MN'=> 'Mongoliska',
        //'no-NO'=> 'Norwegian',
        'nb-NO'=> 'Norwegian Bokmål',
        //'nn-NO'=> 'Norwegian Nynorsk',
        'fa-IR'=> 'Persiska',
        'pl-PL'=> 'Polska',
        'pt-PT'=> 'Portugisiska',
        'pt-BR'=> 'Portugisiska, Brasilien',
        'ro-RO'=> 'Rumänska',
        'ru-RU'=> 'Ryska',
        'sr-CS' => 'Serbiska (latinsk)',
        'sk-SK'=> 'Slovakiska',
        'sl-SI'=> 'Slovenska',
        'so-SO'=> 'Somali',
        'es-ES'=> 'Spanska',
        'es-CO'=> 'Spanska, Colombia',
        'es-MX'=> 'Spanska, Mexiko',
        'es-VE'=> 'Spanska, Venezuela',
        'sv-SE'=> 'Svenska',
        'tl-PH'=> 'Tagalog',
        'ta-IN'=> 'Tamilska',
        'th-TH'=> 'Thailändska',
        'tr-TR'=> 'Turkiska',
        'uk-UA'=> 'Ukrainska',
        'vi-VN'=> 'Vietnamesiska',
        'cy-GB'=> 'Walesiska',
        'zu-ZA'=> 'Zulu',
    ],

    'select_country' => 'Select a Country',
    
    'countries' => [
        'AC'=>'Ön Ascension',
        'AD'=>'Andorra',
        'AE'=>'Förenade Arabemiraten',
        'AF'=>'Afganistan',
        'AG'=>'Antigua och Barbuda',
        'AI'=>'Anguilla',
        'AL'=>'Albanien',
        'AM'=>'Armenien',
        'AN'=>'Aragonesiska',
        'AO'=>'Angola',
        'AQ'=>'Antarktis',
        'AR'=>'Argentina',
        'AS'=>'Amerikanska Samoa',
        'AT'=>'Österrike',
        'AU'=>'Australien',
        'AW'=>'Aruba',
        'AX'=>'Åland',
        'AZ'=>'Azerbajdzjan',
        'BA'=>'Bosnien och Hercegovina',
        'BB'=>'Barbados',
        'BE'=>'Belgien',
        'BD'=>'Bangladesh',
        'BF'=>'Burkina Faso',
        'BG'=>'Bulgarien',
        'BH'=>'Bahrain',
        'BI'=>'Burundi',
        'BJ'=>'Benin',
        'BM'=>'Bermuda',
        'BN'=>'Brunei Darussalam',
        'BO'=>'Bolivien',
        'BR'=>'Brasilien',
        'BS'=>'Bahamas',
        'BT'=>'Bhutan',
        'BV'=>'Bouvetön',
        'BW'=>'Botswana',
        'BY'=>'Vitryssland',
        'BZ'=>'Belize',
        'CA'=>'Kanada',
        'CC'=>'Kokosöarna (Keeling)',
        'CD'=>'Kongo (Demokratiska republiken)',
        'CF'=>'Centralafrikanska republiken',
        'CG'=>'Kongo (Republiken)',
        'CH'=>'Schweiz',
        'CI'=>'Elfenbenskusten',
        'CK'=>'Cooköarna',
        'CL'=>'Chile',
        'CM'=>'Kamerun',
        'CN'=>'Folkrepubliken Kina',
        'CO'=>'Colombia',
        'CR'=>'Costa Rica',
        'CU'=>'Kuba',
        'CV'=>'Kap Verde',
        'CX'=>'Julön',
        'CY'=>'Cypern',
        'CZ'=>'Tjeckien',
        'DE'=>'Tyskland',
        'DJ'=>'Djibouti',
        'DK'=>'Danmark',
        'DM'=>'Dominica',
        'DO'=>'Dominikanska republiken',
        'DZ'=>'Algeriet',
        'EC'=>'Ecuador',
        'EE'=>'Estland',
        'EG'=>'Egypten',
        'GB-ENG'=>'England',
        'ER'=>'Eritrea',
        'ES'=>'Spanien',
        'ET'=>'Etiopien',
        'EU'=>'Europeiska unionen',
        'FI'=>'Finland',
        'FJ'=>'Fiji',
        'FK'=>'Falklandsöarna (Malvinas)',
        'FM'=>'Mikronesiens federerade stater',
        'FO'=>'Färöarna',
        'FR'=>'Frankrike',
        'GA'=>'Gabon',
        'GD'=>'Grenada',
        'GE'=>'Georgien',
        'GF'=>'Franska Guyana',
        'GG'=>'Guernsey',
        'GH'=>'Ghana',
        'GI'=>'Gibraltar',
        'GL'=>'Grönland',
        'GM'=>'Gambia',
        'GN'=>'Guinea',
        'GP'=>'Guadeloupe',
        'GQ'=>'Ekvatorialguinea',
        'GR'=>'Grekland',
        'GS'=>'Sydgeorgien och Sydsandwichöarna',
        'GT'=>'Guatemala',
        'GU'=>'Guam',
        'GW'=>'Guinea-Bissau',
        'GY'=>'Guyana',
        'HK'=>'Hongkong',
        'HM'=>'Heard och McDonaldöarna',
        'HN'=>'Honduras',
        'HR'=>'Kroatien (lokalt namn: Hrvatska)',
        'HT'=>'Haiti',
        'HU'=>'Ungern',
        'ID'=>'Indonesien',
        'IE'=>'Irland',
        'IL'=>'Israel',
        'IM'=>'Isle of Man',
        'IN'=>'Indien',
        'IO'=>'Brittiska territoriet i Indiska oceanen',
        'IQ'=>'Irak',
        'IR'=>'Iran',
        'IS'=>'Island',
        'IT'=>'Italien',
        'JE'=>'Jersey',
        'JM'=>'Jamaica',
        'JO'=>'Jordanien',
        'JP'=>'Japan',
        'KE'=>'Kenya',
        'KG'=>'Kirgizistan',
        'KH'=>'Kambodja',
        'KI'=>'Kiribati',
        'KM'=>'Komorerna',
        'KN'=>'Saint Kitts och Nevis',
        'KR'=>'Republiken Korea',
        'KW'=>'Kuwait',
        'KY'=>'Caymanöarna',
        'KZ'=>'Kazakhstan',
        'LA'=>'Demokratiska folkrepubliken Laos',
        'LB'=>'Libanon',
        'LC'=>'Sankt Lucia',
        'LI'=>'Liechtenstein',
        'LK'=>'Sri Lanka',
        'LR'=>'Liberia',
        'LS'=>'Lesotho',
        'LT'=>'Litauen',
        'LU'=>'Luxemburg',
        'LV'=>'Lettland',
        'LY'=>'Libyska Arabiska Jamahiriyahn',
        'MA'=>'Marocko',
        'MC'=>'Monaco',
        'MD'=>'Moldavien, republiken av',
        'ME'=>'Montenegro',
        'MG'=>'Madagaskar',
        'MH'=>'Marshallöarna',
        'MK'=>'Nordmakedonien, f.d. Jugoslaviska Republiken',
        'ML'=>'Mali',
        'MM'=>'Myanmar',
        'MN'=>'Mongoliet',
        'MO'=>'Macao',
        'MP'=>'Nordmarianerna',
        'MQ'=>'Martinique',
        'MR'=>'Mauretanien',
        'MS'=>'Montserrat',
        'MT'=>'Malta',
        'MU'=>'Mauritius',
        'MV'=>'Maldiverna',
        'MW'=>'Malawi',
        'MX'=>'Mexiko',
        'MY'=>'Malaysia',
        'MZ'=>'Moçambique',
        'NA'=>'Namibia',
        'NC'=>'Nya Kaledonien',
        'NE'=>'Niger',
        'NF'=>'Norfolkön',
        'NG'=>'Nigeria',
        'NI'=>'Nicaragua',
        'NL'=>'Nederländerna',
        'GB-NIR' => 'Northern Ireland',
        'NO'=>'Norge',
        'NP'=>'Nepal',
        'NR'=>'Nauru',
        'NU'=>'Niue',
        'NZ'=>'Nya Zeeland',
        'OM'=>'Oman',
        'PA'=>'Panama',
        'PE'=>'Peru',
        'PF'=>'Franska Polynesien',
        'PG'=>'Papua Nya Guinea',
        'PH'=>'Filippinerna',
        'PK'=>'Pakistan',
        'PL'=>'Polen',
        'PM'=>'S:t Pierre och Miquelon',
        'PN'=>'Pitcairn',
        'PR'=>'Puerto Rico',
        'PS'=>'Palestina',
        'PT'=>'Portugal',
        'PW'=>'Palau',
        'PY'=>'Paraguay',
        'QA'=>'Qatar',
        'RE'=>'Reunion',
        'RO'=>'Rumänien',
        'RS'=>'Serbien',
        'RU'=>'Ryssland',
        'RW'=>'Rwanda',
        'SA'=>'Saudiarabien',
        'GB-SCT'=>'Skottland',
        'SB'=>'Salomonöarna',
        'SC'=>'Seychellerna',
        'SS'=>'Södra Sudan',
        'SD'=>'Sudan',
        'SE'=>'Sverige',
        'SG'=>'Singapore',
        'SH'=>'S:t Helena',
        'SI'=>'Slovenien',
        'SJ'=>'Svalbard- och Jan Mayenöarna',
        'SK'=>'Slovakien (Slovakiska republiken)',
        'SL'=>'Sierra Leone',
        'SM'=>'San Marino',
        'SN'=>'Senegal',
        'SO'=>'Somalien',
        'SR'=>'Surinam',
        'ST'=>'Sao Tome och Principe',
        'SU'=>'Sovjetunionen',
        'SV'=>'El Salvador',
        'SY'=>'Syriska Arabiska Republiken',
        'SZ'=>'Swaziland',
        'TC'=>'Turks- och Caicosöarna',
        'TD'=>'Tchad',
        'TF'=>'Franska Södra Territorierna',
        'TG'=>'Togo',
        'TH'=>'Thailand',
        'TJ'=>'Tadzjikistan',
        'TK'=>'Tokelau',
        'TI'=>'Östtimor',
        'TM'=>'Turkmenistan',
        'TN'=>'Tunisien',
        'TO'=>'Tonga',
        'TP'=>'Östtimor (gammal kod)',
        'TR'=>'Turkiet',
        'TT'=>'Trinidad och Tobago',
        'TV'=>'Tuvalu',
        'TW'=>'Taiwan',
        'TZ'=>'Tanzania, förenade republiken av',
        'UA'=>'Ukraina',
        'UG'=>'Uganda',
        'UK'=>'Storbritannien',
        'US'=>'USA',
        'UM'=>'Förenta staternas yttre småöar',
        'UY'=>'Uruguay',
        'UZ'=>'Uzbekistan',
        'VA'=>'Vatikanstaten (Heliga stolen)',
        'VC'=>'Sankt Vincent och Grenadinerna',
        'VE'=>'Venezuela',
        'VG'=>'Jungfruöarna (brittiska)',
        'VI'=>'Jungfruöarna (USA)',
        'VN'=>'Vietnam',
        'VU'=>'Vanuatu',
        'GB-WLS' =>'Wales',
        'WF'=>'Wallis- och Futunaöarna',
        'WS'=>'Samoa',
        'YE'=>'Jemen',
        'YT'=>'Mayotte',
        'ZA'=>'Sydafrika',
        'ZM'=>'Zambia',
        'ZW'=>'Zimbabwe',
    ],
];

==> snipe-it-8.0.1.zip: snipe-it-8.0.1/resources/lang/sv-SE/localizations.php <==
<?php

return [

    'select_language' => 'Välj ett språk',
    'languages' => [
        'en-US'=> 'Engelska, USA',
        'en-GB'=> 'Engelska, Storbritannien',
        'am-ET' => 'Amharic',
        'af-ZA'=> 'Afrikaans',
        'ar-SA'=> 'Arabiska',
        'bg-BG'=> 'Bulgariska',
        'zh-CN'=> 'Kinesiska, förenklad',
        'zh-TW'=> 'Kinesiska traditionell',
        'ca-ES' => 'Katalanska',
        'hr-HR'=> 'Kroatiska',
        'cs-CZ'=> 'Tjeckiska',
        'da-DK'=> 'Danska',
        'nl-NL'=> 'Nederländska',
        'en-ID'=> 'Engelska, Indonesien',
        'et-EE'=> 'Estniska',
        'fil-PH'=> 'Filippinska',
        'fi-FI'=> 'Finska',
        'fr-FR'=> 'Franska',
        'de-DE'=> 'Tyska',
        'de-if'=> 'Tyska (informellt)',
        'el-GR'=> 'Grekiska',
        'he-IL'=> 'Hebreiska',
        'hu-HU'=> 'Ungerska',
        'is-IS' => 'Isländska',
        'id-ID'=> 'Indonesiska',
        'ga-IE'=> 'Irländska',
        'it-IT'=> 'Italienska',
        'ja-JP'=> 'Japanska',
        'km-KH'=>'Khmer',
        'ko-KR'=> 'Koreanska',
        'lt-LT'=>'Litauiska',
        'lv-LV'=> 'Lettiska',
        'mk-MK'=> 'Makedonska',
        'ms-MY'=> 'Malajiska',
        'mi-NZ'=> 'Maori',
        'mn-MN'=> 'Mongoliska',
        //'no-NO'=> 'Norwegian',
        'nb-NO'=> 'Norsk bokmål',
        //'nn-NO'=> 'Norwegian Nynorsk',
        'fa-IR'=> 'Persiska',
        'pl-PL'=> 'Polska',
        'pt-PT'=> 'Portugisiska',
        'pt-BR'=> 'Portugisiska, Brasilien',
        'ro-RO'=> 'Rumänska',
        'ru-RU'=> 'Ryska',
        'sr-CS' => 'Serbiska (latinsk)',
        'sk-SK'=> 'Slovakiska',
        'sl-SI'=> 'Slovenska',
        'so-SO'=> 'Somali',
        'es-ES'=> 'Spanska',
        'es-CO'=> 'Spanska, Colombia',
        'es-MX'=> 'Spanska, Mexiko',
        'es-VE'=> 'Spanska, Venezuela',
        'sv-SE'=> 'Svenska',
        'tl-PH'=> 'Tagalog',
        'ta-IN'=> 'Tamilska',
        'th-TH'=> 'Thailändska',
        'tr-TR'=> 'Turkiska',
        'uk-UA'=> 'Ukrainska',
        'vi-VN'=> 'Vietnamesiska',
        'cy-GB'=> 'Walesiska',
        'zu-ZA'=> 'Zulu',
    ],

    'select_country' => 'Välj ett land',
    
    'countries' => [
        'AC'=>'Ön Ascension',
        'AD'=>'Andorra',
        'AE'=>'Förenade Arabemiraten',
        'AF'=>'Afganistan',
        'AG'=>'Antigua och Barbuda',
        'AI'=>'Anguilla',
        'AL'=>'Albanien',
        'AM'=>'Armenien',
        'AN'=>'Aragonesiska',
        'AO'=>'Angola',
        'AQ'=>'Antarktis',
        'AR'=>'Argentina',
        'AS'=>'Amerikanska Samoa',
        'AT'=>'Österrike',
        'AU'=>'Australien',
        'AW'=>'Aruba',
        'AX'=>'Åland',
        'AZ'=>'Azerbajdzjan',
        'BA'=>'Bosnien och Hercegovina',
        'BB'=>'Barbados',
        'BE'=>'Belgien',
        'BD'=>'Bangladesh',
        'BF'=>'Burkina Faso',
        'BG'=>'Bulgarien',
        'BH'=>'Bahrain',
        'BI'=>'Burundi',
        'BJ'=>'Benin',
        'BM'=>'Bermuda',
        'BN'=>'Brunei Darussalam',
        'BO'=>'Bolivien',
        'BR'=>'Brasilien',
        'BS'=>'Bahamas',
        'BT'=>'Bhutan',
        'BV'=>'Bouvetön',
        'BW'=>'Botswana',
        'BY'=>'Vitryssland',
        'BZ'=>'Belize',
        'CA'=>'Kanada',
        'CC'=>'Kokosöarna (Keeling)',
        'CD'=>'Kongo (Demokratiska republiken)',
        'CF'=>'Centralafrikanska republiken',
        'CG'=>'Kongo (Republiken)',
        'CH'=>'Schweiz',
        'CI'=>'Elfenbenskusten',
        'CK'=>'Cooköarna',
        'CL'=>'Chile',
        'CM'=>'Kamerun',
        'CN'=>'Folkrepubliken Kina',
        'CO'=>'Colombia',
        'CR'=>'Costa Rica',
        'CU'=>'Kuba',
        'CV'=>'Kap Verde',
        'CX'=>'Julön',
        'CY'=>'Cypern',
        'CZ'=>'Tjeckien',
        'DE'=>'Tyskland',
        'DJ'=>'Djibouti',
        'DK'=>'Danmark',
        'DM'=>'Dominica',
        'DO'=>'Dominikanska republiken',
        'DZ'=>'Algeriet',
        'EC'=>'Ecuador',
        'EE'=>'Estland',
        'EG'=>'Egypten',
        'GB-ENG'=>'England',
        'ER'=>'Eritrea',
        'ES'=>'Spanien',
        'ET'=>'Etiopien',
        'EU'=>'Europeiska unionen',
        'FI'=>'Finland',
        'FJ'=>'Fiji',
        'FK'=>'Falklandsöarna (Malvinas)',
        'FM'=>'Mikronesiens federerade stater',
        'FO'=>'Färöarna',
        'FR'=>'Frankrike',
        'GA'=>'Gabon',
        'GD'=>'Grenada',
        'GE'=>'Georgien',
        'GF'=>'Franska Guyana',
        'GG'=>'Guernsey',
        'GH'=>'Ghana',
        'GI'=>'Gibraltar',
        'GL'=>'Grönland',
        'GM'=>'Gambia',
        'GN'=>'Guinea',
        'GP'=>'Guadeloupe',
        'GQ'=>'Ekvatorialguinea',
        'GR'=>'Grekland',
        'GS'=>'Sydgeorgien och Sydsandwichöarna',
        'GT'=>'Guatemala',
        'GU'=>'Guam',
        'GW'=>'Guinea-Bissau',
        'GY'=>'Guyana',
        'HK'=>'Hongkong',
        'HM'=>'Heard och McDonaldöarna',
        'HN'=>'Honduras',
        'HR'=>'Kroatien (lokalt namn: Hrvatska)',
        'HT'=>'Haiti',
        'HU'=>'Ungern',
        'ID'=>'Indonesien',
        'IE'=>'Irland',
        'IL'=>'Israel',
        'IM'=>'Isle of Man',
        'IN'=>'Indien',
        'IO'=>'Brittiska territoriet i Indiska oceanen',
        'IQ'=>'Irak',
        'IR'=>'Iran',
        'IS'=>'Island',
        'IT'=>'Italien',
        'JE'=>'Jersey',
        'JM'=>'Jamaica',
        'JO'=>'Jordanien',
        'JP'=>'Japan',
        'KE'=>'Kenya',
        'KG'=>'Kirgizistan',
        'KH'=>'Kambodja',
        'KI'=>'Kiribati',
        'KM'=>'Komorerna',
        'KN'=>'Saint Kitts och Nevis',
        'KR'=>'Republiken Korea',
        'KW'=>'Kuwait',
        'KY'=>'Caymanöarna',
        'KZ'=>'Kazakhstan',
        'LA'=>'Demokratiska folkrepubliken Laos',
        'LB'=>'Libanon',
        'LC'=>'Sankt Lucia',
        'LI'=>'Liechtenstein',
        'LK'=>'Sri Lanka',
        'LR'=>'Liberia',
        'LS'=>'Lesotho',
        'LT'=>'Litauen',
        'LU'=>'Luxemburg',
        'LV'=>'Lettland',
        'LY'=>'Libyska Arabiska Jamahiriyahn',
        'MA'=>'Marocko',
        'MC'=>'Monaco',
        'MD'=>'Moldavien, republiken av',
        'ME'=>'Montenegro',
        'MG'=>'Madagaskar',
        'MH'=>'Marshallöarna',
        'MK'=>'Nordmakedonien, f.d. Jugoslaviska Republiken',
        'ML'=>'Mali',
        'MM'=>'Myanmar',
        'MN'=>'Mongoliet',
        'MO'=>'Macao',
        'MP'=>'Nordmarianerna',
        'MQ'=>'Martinique',
        'MR'=>'Mauretanien',
        'MS'=>'Montserrat',
        'MT'=>'Malta',
        'MU'=>'Mauritius',
        'MV'=>'Maldiverna',
        'MW'=>'Malawi',
        'MX'=>'Mexiko',
        'MY'=>'Malaysia',
        'MZ'=>'Moçambique',
        'NA'=>'Namibia',
        'NC'=>'Nya Kaledonien',
        'NE'=>'Niger',
        'NF'=>'Norfolkön',
        'NG'=>'Nigeria',
        'NI'=>'Nicaragua',
        'NL'=>'Nederländerna',
        'GB-NIR' => 'Nordirland',
        'NO'=>'Norge',
        'NP'=>'Nepal',
        'NR'=>'Nauru',
        'NU'=>'Niue',
        'NZ'=>'Nya Zeeland',
        'OM'=>'Oman',
        'PA'=>'Panama',
        'PE'=>'Peru',
        'PF'=>'Franska Polynesien',
        'PG'=>'Papua Nya Guinea',
        'PH'=>'Filippinerna',
        'PK'=>'Pakistan',
        'PL'=>'Polen',
        'PM'=>'S:t Pierre och Miquelon',
        'PN'=>'Pitcairn',
        'PR'=>'Puerto Rico',
        'PS'=>'Palestina',
        'PT'=>'Portugal',
        'PW'=>'Palau',
        'PY'=>'Paraguay',
        'QA'=>'Qatar',
        'RE'=>'Reunion',
        'RO'=>'Rumänien',
        'RS'=>'Serbien',
        'RU'=>'Ryssland',
        'RW'=>'Rwanda',
        'SA'=>'Saudiarabien',
        'GB-SCT'=>'Skottland',
        'SB'=>'Salomonöarna',
        'SC'=>'Seychellerna',
        'SS'=>'Södra Sudan',
        'SD'=>'Sudan',
        'SE'=>'Sverige',
        'SG'=>'Singapore',
        'SH'=>'S:t Helena',
        'SI'=>'Slovenien',
        'SJ'=>'Svalbard- och Jan Mayenöarna',
        'SK'=>'Slovakien (Slovakiska republiken)',
        'SL'=>'Sierra Leone',
        'SM'=>'San Marino',
        'SN'=>'Senegal',
        'SO'=>'Somalien',
        'SR'=>'Surinam',
        'ST'=>'Sao Tome och Principe',
        'SU'=>'Sovjetunionen',
        'SV'=>'El Salvador',
        'SY'=>'Syriska Arabiska Republiken',
        'SZ'=>'Swaziland',
        'TC'=>'Turks- och Caicosöarna',
        'TD'=>'Tchad',
        'TF'=>'Franska Södra Territorierna',
        'TG'=>'Togo',
        'TH'=>'Thailand',
        'TJ'=>'Tadzjikistan',
        'TK'=>'Tokelau',
        'TI'=>'Östtimor',
        'TM'=>'Turkmenistan',
        'TN'=>'Tunisien',
        'TO'=>'Tonga',
        'TP'=>'Östtimor (gammal kod)',
        'TR'=>'Turkiet',
        'TT'=>'Trinidad och Tobago',
        'TV'=>'Tuvalu',
        'TW'=>'Taiwan',
        'TZ'=>'Tanzania, förenade republiken av',
        'UA'=>'Ukraina',
        'UG'=>'Uganda',
        'UK'=>'Storbritannien',
        'US'=>'USA',
        'UM'=>'Förenta staternas yttre småöar',
        'UY'=>'Uruguay',
        'UZ'=>'Uzbekistan',
        'VA'=>'Vatikanstaten (Heliga stolen)',
        'VC'=>'Sankt Vincent och Grenadinerna',
        'VE'=>'Venezuela',
        'VG'=>'Jungfruöarna (brittiska)',
        'VI'=>'Jungfruöarna (USA)',
        'VN'=>'Vietnam',
        'VU'=>'Vanuatu',
        'GB-WLS' =>'Wales',
        'WF'=>'Wallis- och Futunaöarna',
        'WS'=>'Samoa',
        'YE'=>'Jemen',
        'YT'=>'Mayotte',
        'ZA'=>'Sydafrika',
        'ZM'=>'Zambia',
        'ZW'=>'Zimbabwe',
    ],
];
